@@ -5,8 +5,9 @@ from __future__ import division, print_function, absolute_import
 import locale
 
 
-from petl.compat import izip_longest, next, xrange
+from petl.compat import izip_longest, next, xrange, BytesIO
 from petl.util.base import Table
+from petl.io.sources import read_source_from_arg, write_source_from_arg
 
 
 def fromxls(filename, sheet=None, use_view=True, **kwargs):
@@ -36,26 +37,31 @@ class XLSView(Table):
         # converted
         if self.use_view:
             from petl.io import xlutils_view
-            wb = xlutils_view.View(self.filename)
-            if self.sheet is None:
-                ws = wb[0]
-            else:
-                ws = wb[self.sheet]
-            for row in ws:
-                yield tuple(row)
-
+            source = read_source_from_arg(self.filename)
+            with source.open('rb') as source2:
+                source3 = source2.read()
+                wb = xlutils_view.View(source3, **self.kwargs)
+                if self.sheet is None:
+                    ws = wb[0]
+                else:
+                    ws = wb[self.sheet]
+                for row in ws:
+                    yield tuple(row)
         else:
             import xlrd
-            with xlrd.open_workbook(filename=self.filename,
-                                    on_demand=True, **self.kwargs) as wb:
-                if self.sheet is None:
-                    ws = wb.sheet_by_index(0)
-                elif isinstance(self.sheet, int):
-                    ws = wb.sheet_by_index(self.sheet)
-                else:
-                    ws = wb.sheet_by_name(str(self.sheet))
-                for rownum in xrange(ws.nrows):
-                    yield tuple(ws.row_values(rownum))
+            source = read_source_from_arg(self.filename)
+            with source.open('rb') as source2:
+                source3 = source2.read()
+                with xlrd.open_workbook(file_contents=source3,
+                                        on_demand=True, **self.kwargs) as wb:
+                    if self.sheet is None:
+                        ws = wb.sheet_by_index(0)
+                    elif isinstance(self.sheet, int):
+                        ws = wb.sheet_by_index(self.sheet)
+                    else:
+                        ws = wb.sheet_by_name(str(self.sheet))
+                    for rownum in xrange(ws.nrows):
+                        yield tuple(ws.row_values(rownum))
 
 
 def toxls(tbl, filename, sheet, encoding=None, style_compression=0,
@@ -92,7 +98,9 @@ def toxls(tbl, filename, sheet, encoding=None, style_compression=0,
                                                         fillvalue=None)):
                 ws.write(r+1, c, label=v, style=style)
 
-    wb.save(filename)
+    target = write_source_from_arg(filename)
+    with target.open('wb') as target2:
+        wb.save(target2)
 
 
 Table.toxls = toxls
